@@ -32,7 +32,7 @@ arma::vec r_g_vMF_Cpp(arma::uword n, arma::uword p, double kappa) {
     double W_proposal = (1.0 - (1.0 + b) * Z) / (1.0 - (1.0 - b) * Z);
 
     // Step 2. Acceptation-rejection sampling, avoiding extreme cases
-    if ((std::abs(W_proposal) < 1.0) &
+    if ((std::abs(W_proposal) < 1.0) &&
         (kappa * W_proposal + q * log(1.0 - x0 * W_proposal) - c > log(U))) {
 
       W(counter) = W_proposal;
